@@ -2,7 +2,7 @@
 """
 @author: Mojtaba Sardarmehni
 
-Input data for the Solid Waste Optimization Life-cycle Framework in Python(SwolfPy)
+Input data for the swolfpy's life_cycle process models
 """
 
 __all__ = [
@@ -19,7 +19,7 @@ __all__ = [
     'SF_Col_Input'
 ]
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 
 from .MC import MC
